"""
Create a plot with theme frequencies per scenario (group).
"""


import matplotlib.pyplot as plt
import numpy as np
import pandas as pd
import seaborn as sns


def get_all_codes():
    
    all_codes_df = pd.read_excel("W:/staff-umbrella/perfectfit/Exp0/User_Input_Paper/Coding/All_codes.xlsx")
    all_other_parties_df = pd.read_excel("W:/staff-umbrella/perfectfit/Exp0/User_Input_Paper/Coding/All_other_parties.xlsx")
    
    # Create list of all codes at the 3 levels
    all_codes_list = []  # all codes at level 3
    
    for col_idx, col in enumerate(all_codes_df.columns.to_list()):
        for code in all_codes_df[col].to_list():
            if not pd.isna(code):
                if not "Other party" in col or not WITH_OTHER_PARTY_SPEC:
                    all_codes_list.append(col + " - " + code)
                else:
                    for other_party in all_other_parties_df["Other party"].to_list():
                        all_codes_list.append(col + " - " + code + " - " + other_party)
    
    return all_codes_list


if __name__ == "__main__":
    
    
    # Set style
    sns.set()
    sns.set_style('white')
    
    
    # Whether to include the specification of the other party as VC, GP, etc.
    WITH_OTHER_PARTY_SPEC = False
    
    
    # Load file with themes
    all_codes_df = pd.read_excel("W:/staff-umbrella/perfectfit/Exp0/User_Input_Paper/Coding/All_codes.xlsx")
    all_other_parties_df = pd.read_excel("W:/staff-umbrella/perfectfit/Exp0/User_Input_Paper/Coding/All_other_parties.xlsx")
    
    
    # Get a list with all codes/themes
    all_codes_list = get_all_codes()
    
    all_codes_list_text = ["   -Pro Human/Contra AI",
                           "*Nature* -Contra Human/Pro AI",
                           "   -Empathy",
                           "   -Benevolence",
                           "   -Integrity",
                           "   -Trusting the user",
                           "   -Accountability",
                           "   -Companionableness",
                           "   -Stranger",
                           "*Social characteristics* -Does not exist",
                           "   -Situational awareness",
                           "   -Problem-solving",
                           "   -Motivation/encouragement",
                           "   -Relevant personal experience",
                           "*Perceived expertise* -Relevant theoretical knowledge",
                           "   -Response speed",
                           "   -Ease of reaching the other party",
                           "   -Availability at the right/sufficient times",
                           "*Availability* -Having other more important things to do",
                           "   -Frequency",
                           "   -Duration",
                           "   -Time/day",
                           "   -Regularity",
                           "*Timing* -Repetition",
                           "*Availability* -Availability at the right/sufficient times",
                           "   -Positive",
                           "*Feelings during/right after the behavior* -Negative",
                           "   -Low",
                           "*Effort expectancy* -High",
                           "   -Novelty",
                           "   -Unsure of usefulness",
                           "   -Helps other people",
                           "   -Improves feelings/mood",
                           "   -Get motivation/encouragement",
                           "   -Get advice/help/tips/ Learn",
                           "   -Feasibility of what behavior aims to do",
                           "   -Other things are more useful",
                           "   -Autonomy", 
                           "*Perceived usefulness for the user* -Allows for comparison with others",
                           "*Price value*   -Perceived benefits do not outweigh monetary cost",
                           "   -Feedback", 
                           "   -Clarity of instructions",
                           "   -Audio quality",
                           "   -Detailed reasoning for usefulness of behavior",
                           "   -Support for using the behavior to quit smoking",
                           "   -Reward for doing the behavior",
                           "   -Dialog vs. single message",
                           "*Missing/required/desired features*   -A different format than an app",
                           "   -Mood", 
                           "   -Strength of craving", 
                           "   -Importance of doing the behavior",
                           "   -Importance of the goal of the behavior",
                           "   -Capability to reach the goal of the behavior",
                           "   -Capability to do the behavior",
                           "   -Autonomy",
                           "   -Motivation to do the behavior",
                           "   -Motivation to reach goals",
                           "   -Plan for doing the behavior",
                           "   -Habit for doing the behavior",
                           "   -Previous experience with the behavior",
                           "*Current state*   -Curiosity",
                           "   -Open-mindedness",
                           "   -Ambitiousness",
                           "   -Conscientiousness",
                           "   -Aggressiveness/Competitiveness",
                           "   -Want for privacy",
                           "*Traits*   -Stubborn",
                           "   -Positive progress",
                           "   -Taking part in a scientific smoking cessation program",
                           "   -Taking part in research",
                           "   -Getting money from Prolific",
                           "   -Other commitment",
                           "   -Conversational sessions themselves",
                           "   -Motivation by virtual coach",
                           "   -Being asked for feedback on activities in next session",
                           "   -Physical activity",
                           "   -Activities themselves",
                           "   -Music",
                           "*Other motivators/facilitators*   -Other",
                           "   -Having prompts/triggers/reminders to do the behavior",
                           "   -Having enough time to do the behavior",
                           "   -Having the necessary material to do the behavior",
                           "   -Environmental barriers",
                           "   -Norms for doing the behavior and/or reaching the goal of the behavior",
                           "   -Feeling part of a group ...",
                           "*Current state* -Support from others ..."]
                        
    
    # Load file with all coded data
    df = pd.read_csv("all_coded_data.csv")
    # lists are saved as multi-line strings
    df['themes'] = [i.split(' ') for i in df['themes'].values]
    df['themes'] = [[int(j.strip("[]\n.")) for j in i if j.strip("[]\n.") in ["0", "1"]] for i in df['themes']]
    
    
    # Get most common themes for each response type
    # We look at groups of response types and at single ones.
    resp_types = [["activity_experience1", "activity_experience2", "activity_experience3",
                   "activity_experience4", "activity_experience5"],
                  ["barriers"], ["motivators"],
                  ["pa_program"],
                   ["hrs_plan_pa", "hrs_plan_smoking", "hrs_reflection_smoking", 
                   "hrs_reflection_pa"],
                    ["hrs_help_button_pa", "hrs_help_button_smoking"],
                    ["failing_pa_goals"], ["motivational_messages"],
                   ["tell_se", "discussion_so"], 
                   ["gp_start", "gp_relapse"], 
                  ["gp_start", "gp_relapse", "activity_experience1", 
                   "activity_experience2", "activity_experience3",
                   "activity_experience4", "activity_experience5",
                   "barriers", "motivators", "tell_se", "discussion_so",
                   "pa_program", "hrs_help_button_pa", "hrs_help_button_smoking",
                   "hrs_plan_pa", "hrs_plan_smoking", "hrs_reflection_smoking", 
                   "hrs_reflection_pa", "failing_pa_goals", "motivational_messages"]]
    
    resp_types_text = ["Activity Experience", "Barriers", 
                      "Motivators", "Follow PA Program", 
                      "Regular HRS\nPlanning/Reflection", "Help Button for HRS", 
                      "Discuss Repeated\nFailure PA", "Receive Motivational\nMessages",
                      "Involve SE", "Involve GP",
                      "Total"]
    
    all_codes_nums = []
    
    for resp_type in resp_types:
        
        df_temp = df[df["response_type"].isin(resp_type)]
        
        codes = np.array([np.array(i) for i in df_temp['themes'].values])
        codes_nums = np.sum(codes, axis = 0)  # number of times each code appears
        
        all_codes_nums.append(codes_nums)
        
    
    cut_off_start = [0]
    cut_off_end = [85]
    
    y_dim = [20]
    marker_magnifier = 500
    colormap = np.array(['dodgerblue', 'darkorange'])
    
    for c in range(len(cut_off_start)):
    
        # Compute percentages
        all_codes_perc = [all_codes_nums[i]/sum(all_codes_nums[i]) for i in range(len(all_codes_nums))]
        
        all_codes_perc_flat = [sublist[i] for sublist in all_codes_perc for i in range(cut_off_start[c], cut_off_end[c] + 1)]
        
        x = [i for i in range(len(resp_types)) for j in range(cut_off_end[c] - cut_off_start[c] + 1)]
        
        y = [j for i in range(len(resp_types)) for j in range(cut_off_end[c] - cut_off_start[c] + 1)]
        
        # We need categories, since we want a different color for the total
        categories = np.array([0 if i < (cut_off_end[c] - cut_off_start[c] + 1) * 10 else 1 for i in range(len(all_codes_perc_flat))])

        fig, ax = plt.subplots(figsize = (12, y_dim[c]))
        sc = plt.scatter(x, y, s = np.array(all_codes_perc_flat) * marker_magnifier, c=colormap[categories],
                    linewidth = 0)
        
        # Legend
        legend_parts = sc.legend_elements("sizes", num=6)
        legend_parts_text = legend_parts[1]
        legend_parts_text = [str(round(float(''.join(i for i in x if i.isdigit()))/marker_magnifier * 100)) + "%" for x in legend_parts_text]
        
        plt.legend(*(legend_parts[0], legend_parts_text), 
                   bbox_to_anchor=(0.12, 1.05), loc='upper left',
                   ncol = 5)
        
        
        # Add separation between user, behavior, etc.
        vlines = [18.5, 47.5, 78.5]
        for v in vlines:
            ax.axhline(y=v, linewidth=2, color="black", alpha = 0.5)
        
        plt.text(-2.9, 9.5, "Other Party")
        plt.text(-2.9, 32.5, "Behavior")
        plt.text(-2.9, 62.5, "User")
        plt.text(-2.9, 81.5, "Environment")
        
        plt.xticks(rotation=90)
        
        # Have y-labels on the right side of the figure
        axgca = plt.gca()
        axgca.yaxis.set_tick_params(pad=5)
        ax.yaxis.set_label_position("right")
        ax.yaxis.tick_right()
        
        # If plotting multiple figures, only plot the x-axis tick labels for
        # the last one
        if c == len(cut_off_start) - 1:
            plt.xticks([i for i in range(len(resp_types))], [str(resp_types_text[i]) for i in range(len(resp_types))])
        else:
            plt.xticks([i for i in range(len(resp_types))], ["" for i in range(len(resp_types))])
        plt.yticks([i for i in range(cut_off_end[c] - cut_off_start[c] + 1)], [all_codes_list_text[i] for i in range(cut_off_start[c], cut_off_end[c] + 1)])
        
        
        # Add some white space around the figure
        plt.subplots_adjust(right=0.5)
        plt.subplots_adjust(bottom=0.10)
                
        plt.savefig("theme_frequencies_" + str(c) + ".jpg", dpi = 1500, 
                    bbox_inches='tight', pad_inches=0)
       
        
            
            