"""
Preprocess activity experience responses.

This means removing rows with not a single activity experience,
and removing activity experience and effort data for not passing at least one attention check.

Author: Nele Albers
Date: February 2022
Input file: Activity_Experiences_Anonym.csv (not provided)
Output file: Activity_Experiences_Anonym_Preprocessed.xlsx
"""


import numpy as np
import pandas as pd


# Read non-preprocessed data
df = pd.read_csv("Activity_Experiences_Anonym.csv")


# Drop rows with not at least one activity experience
df = df.dropna(subset = ["activity_experience1"])
df = df.reset_index(drop = True)

df_prep = df.copy(deep = True)


columns_exp = ["activity_experience1", "activity_experience2", 
               "activity_experience3", "activity_experience4"]

columns_mod = ["activity_experience_mod1", "activity_experience_mod2", 
               "activity_experience_mod3", "activity_experience_mod4"]


# Remove data for failing attention checks
for row in range(len(df)):

    ac1_list = df.loc[row, "attention_check_list"].split("|")

    # Activity experiences are gathered in sessions 2-5
    for session in range(1, min(5, len(ac1_list))):

        ac1 = ac1_list[session]  # Answer to first attention check question

        if not ac1 in ["3" ,"4"]:  # If first attention check is wrong

            ac2_list = df.loc[row, "attention_check_2_list"].split("|")

            # No data on second attention check
            if session >= len(ac2_list):

                df_prep.loc[row, columns_exp[session - 1]] = np.nan
                df_prep.loc[row, columns_mod[session - 1]] = np.nan
                reward_list_old = df_prep.loc[row, "reward_list"].split("|")
                df_prep.loc[row, "reward_list"] = "|".join(reward_list_old[0:-1])
                print(session, df.loc[row, "rand_id"])

            # Failed second attention check
            elif not ac2_list[session] in ["0", "1"]:

                df_prep.loc[row, columns_exp[session - 1]] = np.nan
                df_prep.loc[row, columns_mod[session - 1]] = np.nan
                reward_list_old = df_prep.loc[row, "reward_list"].split("|")
                df_prep.loc[row, "reward_list"] = "|".join(reward_list_old[0:-1])
                print(session, df.loc[row, "rand_id"])


# Drop rows that now no longer have at least one activity experience answer
df_prep = df_prep.dropna(subset = ["activity_experience1"])
df_prep = df_prep.reset_index(drop = True)
 

# Save pre-processed data       
df_prep.to_excel("Activity_Experiences_Anonym_Preprocessed.xlsx", index = False)
