"""
Pre-process anonymized post-questionnaire data.

Author: Nele Albers
Date: February 2022
Input file: Post_questionnaire_Anonym.xlsx (not provided)
Output file: Post_Questionnaire_Anonym_Preprocessed.xlsx
"""


import numpy as np
import pandas as pd


# Load un-prprocessed data
df_post_q = pd.read_excel("Data/Post_questionnaire_Anonym.xlsx")


# Remove rows without data on first attention check
df_post_q = df_post_q.dropna(subset = ["Check1"])
df_post_q = df_post_q.reset_index(drop = True)


# We accept different spellings for the second attention check
df_post_q["Check2"] = df_post_q["Check2"].replace(np.nan, '')
df_post_q["Check2"] = [str(df_post_q.loc[i, "Check2"]).lower().rstrip('.\'\’').lstrip('.\'\’\‘').strip() for i in range(len(df_post_q))]


# Remove people not passing both attention checks
df_post_q = df_post_q[(df_post_q["Check1"] == 5) | df_post_q["Check2"].isin(['color', 'colour', 'colore', ""])]
df_post_q = df_post_q.reset_index(drop = True)


# Keep first recorded submission for people who started multiple times.
df_post_q_prep = df_post_q.drop_duplicates(subset = 'rand_id', keep = "first")


# Save preprocessed data
df_post_q_prep.to_excel("Data/Post_Questionnaire_Anonym_Preprocessed.xlsx", 
                        index = False)
