# Users' needs for a digital smoking cessation application and how to address them: A mixed-methods study
## Bayesian Power Analysis for Quantitative Analysis


**Author**: Nele Albers
**Date**: June 2022


This file is meant to guide you through reproducing our reported Bayesian power analysis results from the "Participants"-section of our paper "Users' needs for a digital smoking cessation application and how to address them: A mixed-methods study."


### Examine Output of Code Run by Us

If you would like to examine the output of the code as run by us, have a look at the file "sample_size.pdf."


### Run Code Yourself

This section is to explain how you can run the code yourself.


#### Requirements

You need to have Docker installed.


#### Steps to Reproduce Analyses

The reproduction of our code is based on Docker and R Studio. Take the following steps:
1. Make sure you have Docker installed. You can check if you do by running `docker -v`.
2. Navigate to the folder this README-file is in.
3. Now you have 2 options:
      - Build the Docker image via `docker build . -t gbna4/user_needs_paper_sample_size`, or
      - Pull the Docker image from Dockerhub via `docker pull gbna4/user_needs_paper_sample_size`.
4. Run the Docker container via `docker run -d -p 8787:8787 -v <path_to_this_directory>:/home/rstudio/analysis -e PASSWORD=<some_password> gbna4/user_needs_paper_sample_size`.
5. Go to localhost:8787.
6. Login with username 'rstudio' and the password chosen in step 4.
7. Navigate to the "analysis"-folder in R Studio.
9. Now you can reproduce the power analysis results by means of the file "sample_size.Rmd."


#### Knitting R Markdown

If you just want to knit an analysis file to a pdf-file, take the following steps:
1. Make sure you have Docker installed.
2. Navigate to the folder this README-file is in.
3. Now you have 2 options:
      - Build the Docker image via `docker build . -t gbna4/user_needs_paper_sample_size`. 
      - Pull the Docker image from Dockerhub via `docker pull gbna4/user_needs_paper_sample_size`.
4. Run an interactive session with the Docker container via `docker run -it -v <path_to_directory_of_this_README_file>:/home/rstudio/analysis gbna4/user_needs_paper_sample_size /bin/bash`.
5. In the interactive session, type `cd /home/rstudio/analysis` to navigate to the analysis-folder.
6. Start an R session via `R`.
7. Import rmarkdown via `library('rmarkdown')`.
8. Knit an R markdown file via `render("<analysis_file>.Rmd", output_file = "<desired_output_file_name>.pdf")`.


### Explanation of Files

This directory contains the following files and folders:
- Dockerfile: the Dockerfile to build the Docker image yourself if you would like to,
- sample_size.pdf: output of code for the Bayesian power analysis as run by us,
- sample_size.Rmd: file to run the code for the Bayesian power analysis yourself,
- JAGS-4.3.0.tar.gz: we need jags for building the Docker image,
- README.md/README.pdf: this README file, and
- references.bib: references used in the .Rmd-file.
