# Users' needs for a digital smoking cessation application and how to address them: A mixed-methods study
## Interaction Scenario Ratings and Participant Characteristics


**Author**: Nele Albers
**Date**: March 2022


This file is meant to guide you through reproducing our reported interaction scenario ratings and participant characteristics.


We provide code for:
   - the interaction scenario ratings (Figure 3), and
   - the participant characteristics (Table S6).


### Examine Output of Code Run by Us

If you would like to examine the output of the code as run by us, have a look at:
   - the file "interaction_scenario_ratings.pdf" for the interaction scenario ratings, and
   - the file "participant_characteristics.pdf" for the participant characteristics.


### Run Code Yourself

This section is to explain how you can run the code yourself.


#### Requirements

You need to have Docker installed.


#### Steps to Reproduce Analyses

The reproduction of our code is based on Docker and R Studio. Take the following steps:
1. Make sure you have Docker installed. You can check if you do by running `docker -v`.
2. Navigate to the folder this README-file is in.
3. Now you have 2 options:
      - Build the Docker image via `docker build . -t gbna4/user_needs_paper_analysis_r`, or
      - Pull the Docker image from Dockerhub via `docker pull gbna4/user_needs_paper_analysis_r`.
4. Run the Docker container via `docker run -d -p 8787:8787 -v <path_to_this_directory>:/home/rstudio/analysis -e PASSWORD=<some_password> gbna4/user_needs_paper_analysis_r`.
5. Go to localhost:8787.
6. Login with username 'rstudio' and the password chosen in step 4.
7. Navigate to the "analysis"-folder in R Studio.
9. Now you can reproduce the interaction scenario ratings via the file "interaction_scenario_ratings.Rmd" and the participant characteristics via the file "participant_characteristics.Rmd."

#### Knitting R Markdown

If you just want to knit an analysis file to a pdf-file, take the following steps:
1. Make sure you have Docker installed.
2. Navigate to the folder this README-file is in.
3. Now you have 2 options:
      - Build the Docker image via `docker build . -t gbna4/user_needs_paper_analysis_r`. 
      - Pull the Docker image from Dockerhub via `docker pull gbna4/user_needs_paper_analysis_r`.
4. Run an interactive session with the Docker container via `docker run -it -v <path_to_directory_of_this_README_file>:/home/rstudio/analysis gbna4/user_needs_paper_analysis_r /bin/bash`.
5. In the interactive session, type `cd /home/rstudio/analysis` to navigate to the analysis-folder.
6. Start an R session via `R`.
7. Import rmarkdown via `library('rmarkdown')`.
8. Knit an R markdown file via `render("<analysis_file>.Rmd", output_file = "<desired_output_file_name>.pdf")`.


### Explanation of Files

This directory contains the following files and folders:
- Data: pre-processed data needed for the analyses,
- Figures: the figure with the interaction scenario ratings as created by us,
- Dockerfile: the Dockerfile to build the Docker image yourself if you would like to,
- interaction_scenario_ratings.pdf: output of code for interaction scenario ratings as run by us,
- interaction_scenario_ratings.Rmd: file to run the code for the interaction scenario ratings yourself,
- participant_characteristics.pdf: output of code for participant characteristics as run by us,
- participant_characteristics.Rmd: file to run the code for the participant characteristics yourself,
- README.md/README.pdf: this README file, and
- references.bib: references used in the .Rmd-files.
